@@ -24,5 +24,6 @@ def get_data(name: str) -> Dict[str, Any]:
     return load_file(name)
 
 
-def get_url(name: str, format = None) -> str:
-    return f"https://docs.hackdiff.rent/.data/{name}.{format}" if format else f"https://docs.hackdiff.rent/.data/{name}.json"
+def get_url(name: str, fmt=None) -> str:
+    fmt = 'json' if fmt is None else fmt
+    return f"https://docs.hackdiff.rent/.data/{name}.{fmt}"
